==> jc-1.4.0.tar.gz: javax/swing/JFormattedTextField__24AbstractFormatterFactory.h <==
// public abstract class javax.swing.JFormattedTextField$AbstractFormatterFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e3da04f50ec7ee11 javax_swing_JFormattedTextField__24AbstractFormatterFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JFormattedTextField__24AbstractFormatterFactory_H_
#define _JC_javax_swing_JFormattedTextField__24AbstractFormatterFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JFormattedTextField$object;
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object;

// Typedefs
typedef struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_refs	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_refs;
typedef struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_nonrefs	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_nonrefs;
typedef struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$refs	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$refs;
typedef struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$nonrefs	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$nonrefs;
typedef struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$object	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$object;

typedef const struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vmethods	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vmethods;
typedef const struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtable	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtable;
typedef const struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtype	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtype;

// Constructors
extern void _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$object *);

// Virtual methods
extern struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object *_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$method$getFormatter$05eb5d4d7bcf381f(_jc_env *, struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$object *, struct _jc_javax_swing_JFormattedTextField$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$method_info$getFormatter$05eb5d4d7bcf381f;

// Virtual methods structure
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vmethods {
	struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object	*(*getFormatter$05eb5d4d7bcf381f)(_jc_env *, struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$object *, struct _jc_javax_swing_JFormattedTextField$object *);
};

// Vtable
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vmethods	javax_swing_JFormattedTextField__24AbstractFormatterFactory;
};

// Vtype
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtype {
	_jc_type			type;
	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$refs {
    _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_refs	javax_swing_JFormattedTextField__24AbstractFormatterFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_nonrefs	javax_swing_JFormattedTextField__24AbstractFormatterFactory;
};

// Object instance structure
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$object {
	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtype	*vtype;
	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtype _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JFormattedTextField__24AbstractFormatterFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$class_object;

#endif	/* _JC_javax_swing_JFormattedTextField__24AbstractFormatterFactory_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JFormattedTextField__24AbstractFormatterFactory.h <==
// public abstract class javax.swing.JFormattedTextField$AbstractFormatterFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e3da04f50ec7ee11 javax_swing_JFormattedTextField__24AbstractFormatterFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JFormattedTextField__24AbstractFormatterFactory_H_
#define _JC_javax_swing_JFormattedTextField__24AbstractFormatterFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JFormattedTextField$object;
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object;

// Typedefs
typedef struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_refs	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_refs;
typedef struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_nonrefs	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_nonrefs;
typedef struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$refs	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$refs;
typedef struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$nonrefs	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$nonrefs;
typedef struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$object	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$object;

typedef const struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vmethods	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vmethods;
typedef const struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtable	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtable;
typedef const struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtype	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtype;

// Constructors
extern void _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object *_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$method$getFormatter$05eb5d4d7bcf381f(_jc_env *, struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$object *, struct _jc_javax_swing_JFormattedTextField$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$method_info$getFormatter$05eb5d4d7bcf381f;

// Virtual methods structure
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vmethods {
	struct _jc_javax_swing_JFormattedTextField__24AbstractFormatter$object	*(*getFormatter$05eb5d4d7bcf381f)(_jc_env *, struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$object *, struct _jc_javax_swing_JFormattedTextField$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vmethods	javax_swing_JFormattedTextField__24AbstractFormatterFactory;
};

// Vtype
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtype {
	_jc_type			type;
	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$refs {
    _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_refs	javax_swing_JFormattedTextField__24AbstractFormatterFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$sub_nonrefs	javax_swing_JFormattedTextField__24AbstractFormatterFactory;
};

// Object instance structure
struct _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$object {
	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtype	*vtype;
	_jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$vtype _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JFormattedTextField__24AbstractFormatterFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JFormattedTextField__24AbstractFormatterFactory$class_object;

#endif	/* _JC_javax_swing_JFormattedTextField__24AbstractFormatterFactory_H_ */
